@@ -144,6 +144,7 @@ sub reg_import
         # this is fairly common in pasted regedit files.
         $lineno++;
         chomp;
+        s/\r$//;
         if (s/\\\s*$//) {
             $_ .= <$fh>;
             redo unless eof ($fh);
@@ -152,8 +153,8 @@ sub reg_import
         #print STDERR "reg_import: parsing <<<$_>>>\n";
 
         if ($state eq "outer") {
-            # Ignore blank lines, headers.
-            next if /^\s*$/;
+            # Ignore blank lines, headers, comments.
+            next if /^\s*(;.*)?$/;
 
             # .* is needed before Windows Registry Editor Version.. in
             # order to eat a possible Unicode BOM which regedit writes
@@ -192,7 +193,7 @@ sub reg_import
                 my $value = _parse_value ("", $1, $encoding);
                 croak (_parse_error ($_, $lineno)) unless defined $value;
                 push @newvalues, $value;
-            } elsif (/^\s*$/) { # blank line after values
+            } elsif (/^\s*(;.*)?$/) { # blank line after values
                 _merge_node ($hmap, \%params, $newnode, \@newvalues, \@delvalues);
                 $state = "outer";
             } else {
@@ -487,11 +488,12 @@ sub reg_export
 {
     my $h = shift;
     my $key = shift;
+    my $fh = shift;
 
     my $node = _node_lookup ($h, $key);
     croak "$key: path not found in this hive" unless $node;
 
-    reg_export_node ($h, $node, @_);
+    reg_export_node ($h, $node, $fh, 0, @_);
 }
 
 =head2 reg_export_node
@@ -510,8 +512,17 @@ sub reg_export_node
     my $h = shift;
     my $node = shift;
     my $fh = shift;
+    my $depth = shift;
     my %params = @_;
 
+    my $max_depth = $params{max_depth};
+    if (defined $max_depth && $max_depth >= 0) {
+        # Check if we've gone deep enough
+        if ($depth >= $max_depth) {
+            return;
+        }
+    }
+
     confess "reg_export_node: \$node parameter was undef" unless defined $node;
 
     # Get the canonical path of this node.
@@ -622,7 +633,7 @@ sub reg_export_node
     }
 
     @children = sort { $h->node_name ($a) cmp $h->node_name ($b) } @children;
-    reg_export_node ($h, $_, $fh, @_) foreach @children;
+    reg_export_node ($h, $_, $fh, $depth + 1, @_) foreach @children;
 }
 
 # Escape " and \ when printing keys.
