@@ -1,5 +1,5 @@
 # hivex Ruby bindings -*- ruby -*-
-# Copyright (C) 2009-2011 Red Hat Inc.
+# Copyright (C) 2009-2014 Red Hat Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,24 +21,23 @@
 # length and offset for this value cell should be 37 bytes, position
 # 8712.
 
-require 'test/unit'
-require 'hivex'
+require File::join(File::dirname(__FILE__), 'test_helper')
 
-class TestRLenValue < Test::Unit::TestCase
+class TestRLenValue < MiniTest::Unit::TestCase
   def test_RLenValue
     h = Hivex::open(File::join(ENV['abs_srcdir'], '..', 'images', 'rlenvalue_test_hive'), {})
-    assert_not_nil(h)
+    refute_nil(h)
 
     root = h.root()
-    assert_not_nil(root)
+    refute_nil(root)
 
     moderate_value_node = h.node_get_child(root, "ModerateValueParent")
-    assert_not_nil(moderate_value_node)
+    refute_nil(moderate_value_node)
 
     moderate_value_value = h.node_get_value(moderate_value_node, "33Bytes")
 
     r = h.value_data_cell_offset(moderate_value_value)
-    assert_equal(r[:len], 37)
-    assert_equal(r[:off], 8712)
+    assert_equal(37, r[:len])
+    assert_equal(8712, r[:off])
   end
 end
