@@ -1,5 +1,5 @@
 # hivex Ruby bindings -*- ruby -*-
-# Copyright (C) 2009-2011 Red Hat Inc.
+# Copyright (C) 2009-2014 Red Hat Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,21 +15,20 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-require 'test/unit'
-require 'hivex'
+require File::join(File::dirname(__FILE__), 'test_helper')
 
-class TestWrite < Test::Unit::TestCase
+class TestWrite < MiniTest::Unit::TestCase
   def test_write
     h = Hivex::open("../images/minimal", {:write => 1})
-    assert_not_nil (h)
+    refute_nil (h)
 
     root = h.root()
-    assert (root)
+    refute_nil (root)
 
     h.node_add_child(root, "A")
     h.node_add_child(root, "B")
     b = h.node_get_child(root, "B")
-    assert (b)
+    refute_nil (b)
 
     values = [
               { :key => "Key1", :type => 3, :value => "ABC" },
